@@ -24,8 +24,6 @@
 #endif
 
 #include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/un.h>
 #include <unistd.h>
 
 #include <e2k-uri.h>
@@ -72,7 +70,7 @@ E2K_MAKE_TYPE (mail_stub, MailStub, class_init, NULL, PARENT_TYPE)
 static void
 free_string_array (GPtrArray *strings)
 {
-	int i;
+	gint i;
 
 	for (i = 0; i < strings->len; i++)
 		g_free (strings->pdata[i]);
@@ -94,7 +92,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 	switch (command) {
 	case CAMEL_STUB_CMD_CONNECT:
 	{
-		char *pwd
+		gchar *pwd
 		d(printf("CONNECT\n"));
 		g_object_ref (stub);
 		if (!mail_stub_read_args (stub,
@@ -108,7 +106,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_GET_FOLDER:
 	{
-		char *folder_name;
+		gchar *folder_name;
 		GPtrArray *uids;
 		GByteArray *flags;
 		GPtrArray *hrefs;
@@ -144,7 +142,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_SYNC_FOLDER:
 	{
-		char *folder_name;
+		gchar *folder_name;
 
 		if (!mail_stub_read_args (stub,
 					  CAMEL_STUB_ARG_FOLDER, &folder_name,
@@ -159,7 +157,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_REFRESH_FOLDER:
 	{
-		char *folder_name;
+		gchar *folder_name;
 
 		if (!mail_stub_read_args (stub,
 					  CAMEL_STUB_ARG_FOLDER, &folder_name,
@@ -172,9 +170,24 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 		break;
 	}
 
+	case CAMEL_STUB_CMD_SYNC_COUNT:
+	{
+		gchar *folder_name;
+
+		if (!mail_stub_read_args (stub,
+					  CAMEL_STUB_ARG_FOLDER, &folder_name,
+					  CAMEL_STUB_ARG_END))
+			goto comm_fail;
+		d(printf("SYNC_COUNT %s\n", folder_name));
+		g_object_ref (stub);
+		MS_CLASS (stub)->sync_count (stub, folder_name);
+		g_free (folder_name);
+		break;
+	}
+
 	case CAMEL_STUB_CMD_EXPUNGE_UIDS:
 	{
-		char *folder_name;
+		gchar *folder_name;
 		GPtrArray *uids;
 
 		if (!mail_stub_read_args (stub,
@@ -192,7 +205,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_APPEND_MESSAGE:
 	{
-		char *folder_name, *subject;
+		gchar *folder_name, *subject;
 		guint32 flags;
 		GByteArray *body;
 
@@ -206,7 +219,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 		d(printf("APPEND_MESSAGE %s %lu %s\n", folder_name,
 			 (gulong)flags, subject));
 		g_object_ref (stub);
-		MS_CLASS (stub)->append_message (stub, folder_name, flags, subject, (char *) body->data, body->len);
+		MS_CLASS (stub)->append_message (stub, folder_name, flags, subject, (gchar *) body->data, body->len);
 		g_free (folder_name);
 		g_free (subject);
 		g_byte_array_free (body, TRUE);
@@ -215,7 +228,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_SET_MESSAGE_FLAGS:
 	{
-		char *folder_name, *uid;
+		gchar *folder_name, *uid;
 		guint32 flags, mask;
 
 		if (!mail_stub_read_args (stub,
@@ -236,7 +249,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_SET_MESSAGE_TAG:
 	{
-		char *folder_name, *uid, *name, *value;
+		gchar *folder_name, *uid, *name, *value;
 
 		if (!mail_stub_read_args (stub,
 					  CAMEL_STUB_ARG_FOLDER, &folder_name,
@@ -259,7 +272,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_GET_MESSAGE:
 	{
-		char *folder_name, *uid;
+		gchar *folder_name, *uid;
 
 		if (!mail_stub_read_args (stub,
 					  CAMEL_STUB_ARG_FOLDER, &folder_name,
@@ -276,7 +289,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_SEARCH_FOLDER:
 	{
-		char *folder_name, *text;
+		gchar *folder_name, *text;
 
 		if (!mail_stub_read_args (stub,
 					  CAMEL_STUB_ARG_FOLDER, &folder_name,
@@ -293,7 +306,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_TRANSFER_MESSAGES:
 	{
-		char *source_name, *dest_name;
+		gchar *source_name, *dest_name;
 		guint32 delete_originals;
 		GPtrArray *uids;
 
@@ -318,7 +331,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_GET_FOLDER_INFO:
 	{
-		char *top;
+		gchar *top;
 		guint32 store_flags;
 
 		if (!mail_stub_read_args (stub,
@@ -335,7 +348,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_SEND_MESSAGE:
 	{
-		char *from;
+		gchar *from;
 		GPtrArray *recips;
 		GByteArray *body;
 
@@ -349,7 +362,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 			 from, recips->len));
 		g_object_ref (stub);
 		MS_CLASS (stub)->send_message (stub, from, recips,
-					       (char *) body->data, body->len);
+					       (gchar *) body->data, body->len);
 		g_free (from);
 		free_string_array (recips);
 		g_byte_array_free (body, TRUE);
@@ -358,7 +371,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_CREATE_FOLDER:
 	{
-		char *parent_name, *folder_name;
+		gchar *parent_name, *folder_name;
 
 		if (!mail_stub_read_args (stub,
 					  CAMEL_STUB_ARG_FOLDER, &parent_name,
@@ -376,7 +389,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_DELETE_FOLDER:
 	{
-		char *folder_name;
+		gchar *folder_name;
 
 		if (!mail_stub_read_args (stub,
 					  CAMEL_STUB_ARG_FOLDER, &folder_name,
@@ -391,7 +404,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_RENAME_FOLDER:
 	{
-		char *old_name, *new_name;
+		gchar *old_name, *new_name;
 
 		if (!mail_stub_read_args (stub,
 					  CAMEL_STUB_ARG_FOLDER, &old_name,
@@ -408,7 +421,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_SUBSCRIBE_FOLDER:
 	{
-		char *folder_name;
+		gchar *folder_name;
 
 		if (!mail_stub_read_args (stub,
 					  CAMEL_STUB_ARG_FOLDER, &folder_name,
@@ -423,7 +436,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_UNSUBSCRIBE_FOLDER:
 	{
-		char *folder_name;
+		gchar *folder_name;
 
 		if (!mail_stub_read_args (stub,
 					  CAMEL_STUB_ARG_FOLDER, &folder_name,
@@ -438,7 +451,7 @@ connection_handler (GIOChannel *source, GIOCondition condition, gpointer data)
 
 	case CAMEL_STUB_CMD_IS_SUBSCRIBED_FOLDER:
 	{
-		char *folder_name;
+		gchar *folder_name;
 
 		if (!mail_stub_read_args (stub,
 					CAMEL_STUB_ARG_FOLDER, &folder_name,
@@ -481,12 +494,12 @@ mail_stub_read_args (MailStub *stub, ...)
 {
 	va_list ap;
 	CamelStubArgType argtype;
-	int status;
+	gint status;
 
 	va_start (ap, stub);
 
 	do {
-		argtype = va_arg (ap, int);
+		argtype = va_arg (ap, gint);
 		switch (argtype) {
 		case CAMEL_STUB_ARG_END:
 			return TRUE;
@@ -503,7 +516,7 @@ mail_stub_read_args (MailStub *stub, ...)
 
 		case CAMEL_STUB_ARG_STRING:
 		{
-			char **buf = va_arg (ap, char **);
+			gchar **buf = va_arg (ap, gchar **);
 
 			status = camel_stub_marshal_decode_string (stub->cmd, buf);
 			break;
@@ -511,7 +524,7 @@ mail_stub_read_args (MailStub *stub, ...)
 
 		case CAMEL_STUB_ARG_FOLDER:
 		{
-			char **buf = va_arg (ap, char **);
+			gchar **buf = va_arg (ap, gchar **);
 
 			status = camel_stub_marshal_decode_folder (stub->cmd, buf);
 			break;
@@ -529,8 +542,8 @@ mail_stub_read_args (MailStub *stub, ...)
 		{
 			GPtrArray **arr = va_arg (ap, GPtrArray **);
 			guint32 len;
-			char *string;
-			int i;
+			gchar *string;
+			gint i;
 
 			status = camel_stub_marshal_decode_uint32 (stub->cmd, &len);
 			if (status == -1)
@@ -563,11 +576,11 @@ mail_stub_read_args (MailStub *stub, ...)
 			}
 			if (status == -1)
 				g_array_free (*arr, TRUE);
-			
+
 			break;
 		}
-		
-		
+
+
 		default:
 			g_critical ("%s: Uncaught case (%d)", G_STRLOC, argtype);
 			status = -1;
@@ -610,7 +623,7 @@ mail_stub_return_data (MailStub *stub, CamelStubRetval retval, ...)
 	va_start (ap, retval);
 
 	while (1) {
-		argtype = va_arg (ap, int);
+		argtype = va_arg (ap, gint);
 		switch (argtype) {
 		case CAMEL_STUB_ARG_END:
 			return;
@@ -625,7 +638,7 @@ mail_stub_return_data (MailStub *stub, CamelStubRetval retval, ...)
 
 		case CAMEL_STUB_ARG_STRING:
 		{
-			char *string = va_arg (ap, char *);
+			gchar *string = va_arg (ap, gchar *);
 
 			camel_stub_marshal_encode_string (marshal, string);
 			break;
@@ -633,7 +646,7 @@ mail_stub_return_data (MailStub *stub, CamelStubRetval retval, ...)
 
 		case CAMEL_STUB_ARG_FOLDER:
 		{
-			char *name = va_arg (ap, char *);
+			gchar *name = va_arg (ap, gchar *);
 
 			camel_stub_marshal_encode_folder (marshal, name);
 			break;
@@ -641,8 +654,8 @@ mail_stub_return_data (MailStub *stub, CamelStubRetval retval, ...)
 
 		case CAMEL_STUB_ARG_BYTEARRAY:
 		{
-			char *data = va_arg (ap, char *);
-			int len = va_arg (ap, int);
+			gchar *data = va_arg (ap, gchar *);
+			gint len = va_arg (ap, gint);
 			GByteArray ba;
 
 			ba.data = (guint8 *) data;
@@ -654,7 +667,7 @@ mail_stub_return_data (MailStub *stub, CamelStubRetval retval, ...)
 		case CAMEL_STUB_ARG_STRINGARRAY:
 		{
 			GPtrArray *arr = va_arg (ap, GPtrArray *);
-			int i;
+			gint i;
 
 			camel_stub_marshal_encode_uint32 (marshal, arr->len);
 			for (i = 0; i < arr->len; i++)
@@ -665,15 +678,15 @@ mail_stub_return_data (MailStub *stub, CamelStubRetval retval, ...)
 		case CAMEL_STUB_ARG_UINT32ARRAY:
 		{
 			GArray *arr = va_arg (ap, GArray *);
-			int i;
+			gint i;
 
 			camel_stub_marshal_encode_uint32 (marshal, arr->len);
 			for (i = 0; i < arr->len; i++)
 				camel_stub_marshal_encode_uint32 (marshal, g_array_index (arr, guint32, i));
 			break;
 		}
-		
-		
+
+
 		default:
 			g_critical ("%s: Uncaught case (%d)", G_STRLOC, argtype);
 			return;
@@ -689,7 +702,7 @@ mail_stub_return_data (MailStub *stub, CamelStubRetval retval, ...)
  * Sends progress data on the current operation.
  **/
 void
-mail_stub_return_progress (MailStub *stub, int percent)
+mail_stub_return_progress (MailStub *stub, gint percent)
 {
 	d(printf("  %d%%", percent));
 	camel_stub_marshal_encode_uint32 (stub->cmd, CAMEL_STUB_RETVAL_PROGRESS);
@@ -731,7 +744,7 @@ mail_stub_return_ok (MailStub *stub)
  * callers should not assume it is still valid after the call.
  **/
 void
-mail_stub_return_error (MailStub *stub, const char *message)
+mail_stub_return_error (MailStub *stub, const gchar *message)
 {
 	d(printf("  Error: %s\n", message));
 	camel_stub_marshal_flush (stub->status);
@@ -764,9 +777,13 @@ mail_stub_push_changes (MailStub *stub)
  * Initializes @stub with @cmd_fd and @status_fd.
  **/
 void
-mail_stub_construct (MailStub *stub, int cmd_fd, int status_fd)
+mail_stub_construct (MailStub *stub, gint cmd_fd, gint status_fd)
 {
+#ifndef G_OS_WIN32
 	stub->channel = g_io_channel_unix_new (cmd_fd);
+#else
+	stub->channel = g_io_channel_win32_new_socket (cmd_fd);
+#endif
 	g_io_add_watch (stub->channel, G_IO_IN | G_IO_ERR | G_IO_HUP,
 			connection_handler, stub);
 	stub->cmd = camel_stub_marshal_new (cmd_fd);
