@@ -4,10 +4,11 @@
 #ifndef __EXCHANGE_COMPONENT_H__
 #define __EXCHANGE_COMPONENT_H__
 
+#include <libedata-book/e-data-book-factory.h>
+#include <libedata-cal/e-data-cal-factory.h>
 #include <bonobo/bonobo-object.h>
 #include <shell/Evolution.h>
 #include <exchange-types.h>
-#include <exchange-offline-listener.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -26,13 +27,16 @@ typedef struct ExchangeComponentClass           ExchangeComponentClass;
 
 struct ExchangeComponent {
 	BonoboObject parent;
-	
+
 	ExchangeComponentPrivate *priv;
 };
 
 struct ExchangeComponentClass {
 	BonoboObjectClass parent_class;
 
+	/* signal default handlers */
+	void (*linestatus_notify) (ExchangeComponent *component, guint status);
+
 	POA_GNOME_Evolution_Component__epv epv;
 };
 
@@ -42,19 +46,18 @@ GType              exchange_component_get_type (void);
 ExchangeComponent *exchange_component_new      (void);
 
 ExchangeAccount   *exchange_component_get_account_for_uri (ExchangeComponent *component,
-							   const char        *uri);
+							   const gchar        *uri);
 gboolean           exchange_component_is_interactive      (ExchangeComponent *component);
-void           exchange_component_is_offline      (ExchangeComponent *component, int *state);
+void           exchange_component_is_offline      (ExchangeComponent *component, gint *state);
 
-void exchange_component_set_offline_listener (ExchangeComponent *component, 
-						ExchangeOfflineListener *listener);
-
-ExchangeOfflineListener *exchange_component_get_offline_listener (ExchangeComponent *component);
+void exchange_component_set_factories (ExchangeComponent *component,
+				       EDataCalFactory *cal_factory,
+				       EDataBookFactory *book_factory);
 
 #define EXCHANGE_COMPONENT_FACTORY_IID  "OAFIID:GNOME_Evolution_Exchange_Component_Factory:" BASE_VERSION
 #define EXCHANGE_COMPONENT_IID		"OAFIID:GNOME_Evolution_Exchange_Component:" BASE_VERSION
-#define EXCHANGE_CALENDAR_FACTORY_ID	"OAFIID:GNOME_Evolution_Exchange_Connector_CalFactory:" BASE_VERSION
-#define EXCHANGE_ADDRESSBOOK_FACTORY_ID	"OAFIID:GNOME_Evolution_Exchange_Connector_BookFactory:" BASE_VERSION
+#define EXCHANGE_CALENDAR_FACTORY_ID	"OAFIID:GNOME_Evolution_Exchange_Connector_CalFactory:" API_VERSION
+#define EXCHANGE_ADDRESSBOOK_FACTORY_ID	"OAFIID:GNOME_Evolution_Exchange_Connector_BookFactory:" API_VERSION
 #define EXCHANGE_AUTOCONFIG_WIZARD_ID	"OAFIID:GNOME_Evolution_Exchange_Connector_Startup_Wizard:" BASE_VERSION
 
 #ifdef __cplusplus
